# Mobel

### Description

Mobel is a library that provides some improvements for the standard Python decorator pattern. It includes the following features:
- A utility function to generate entities that combine decorator and decorator Factory in one easy to use function
- A method to annotate functions similar to Java. This does not affect the function itself but provides a way to mark them as having certain properties
- A method to pipe decorators and create a combined decorator ( or decorator factory )

for details on how to implement these features you can check out the [docs](DOCS.md)
